==> hydromt_fiat-0.3.2.tar.gz: hydromt_fiat-0.3.2/tests/test_vulnerability_exposure_global_default.py <==
from hydromt_fiat.fiat import FiatModel
from hydromt.log import setuplog
from pathlib import Path
import pytest
import shutil
import geopandas as gpd


EXAMPLEDIR = Path(
    "P:/11207949-dhs-phaseii-floodadapt/Model-builder/Delft-FIAT/local_test_database"
)
DATADIR = Path().absolute() / "hydromt_fiat" / "data"
EXAMPLEDATADIR = Path().absolute() / "examples" / "data"

_region = {
    "type": "FeatureCollection",
    "features": [
        {
            "type": "Feature",
            "properties": {},
            "geometry": {
                "coordinates": [
                    [
                        [-0.32388413292315477, 53.73732589790447],
                        [-0.2844094169901439, 53.73884202781184],
                        [-0.24185874916557282, 53.72549820752624],
                        [-0.23878279727406948, 53.77430385636828],
                        [-0.31055500806266423, 53.81821073959722],
                        [-0.3884791226331288, 53.82426325446718],
                        [-0.4499981604528216, 53.79429475800947],
                        [-0.431029790458922, 53.71154332085726],
                        [-0.32388413292315477, 53.73732589790447],
                    ]
                ],
                "type": "Polygon",
            },
        }
    ],
}

_cases = {
    "vulnerability_and_exposure_OSM_only": {
        "dir": "vulnerability_and_exposure_OSM_only",
        "data_catalogue": DATADIR / "hydromt_fiat_catalog_global.yml",
        "configuration": {
            "setup_global_settings": {"crs": "epsg:4326"},
            "setup_output": {
                "output_dir": "output",
                "output_csv_name": "output.csv",
                "output_vector_name": "spatial.gpkg",
            },
            "setup_vulnerability": {
                "vulnerability_fn": "jrc_vulnerability_curves",
                "continent": "Europe",
                "vulnerability_identifiers_and_linking_fn": "jrc_vulnerability_curves_linking",
                "unit": "m",
            },
            "setup_exposure_buildings": {
                "asset_locations": "OSM",
                "occupancy_type": "OSM",
                "max_potential_damage": "jrc_damage_values",
                "ground_floor_height": 0,
                "damage_types": ["structure", "content"],
                "unit": "m",
                "country": "United Kingdom",
            },
        },
        "region": _region,
    }
}


@pytest.mark.parametrize("case", list(_cases.keys()))
def test_vulnerability_and_exposure_global_default(case):
    # Read model in examples folder.
    root = EXAMPLEDIR.joinpath(_cases[case]["dir"])
    if root.exists():
        shutil.rmtree(root)

    logger = setuplog("hydromt_fiat", log_level=10)
    data_catalog_yml = str(_cases[case]["data_catalogue"])
    fm = FiatModel(root=root, mode="w", data_libs=[data_catalog_yml], logger=logger)

    region = gpd.GeoDataFrame.from_features(_cases[case]["region"], crs=4326)
    fm.build(region={"geom": region}, opt=_cases[case]["configuration"])
    fm.write()

    # Check if the exposure data exists
    assert root.joinpath("exposure", "buildings.gpkg").exists()
    assert root.joinpath("exposure", "exposure.csv").exists()
    assert root.joinpath("exposure", "region.gpkg").exists()

    # Check if the vulnerability data exists
    assert root.joinpath("vulnerability", "vulnerability_curves.csv").exists()

    # Check if the hazard folder exists
    assert root.joinpath("hazard").exists()

    # Check if the output data folder exists
    assert root.joinpath("output").exists()

==> hydromt_fiat-0.5.3.tar.gz: hydromt_fiat-0.5.3/tests/test_vulnerability_exposure_global_default.py <==
from hydromt_fiat.fiat import FiatModel
from hydromt.log import setuplog
from pathlib import Path
import pytest
import shutil
import geopandas as gpd


EXAMPLEDIR = Path(
    "P:/11207949-dhs-phaseii-floodadapt/Model-builder/Delft-FIAT/local_test_database"
)
DATADIR = Path().absolute() / "hydromt_fiat" / "data"
EXAMPLEDATADIR = Path().absolute() / "examples" / "data"

_region = {
    "type": "FeatureCollection",
    "features": [
        {
            "type": "Feature",
            "properties": {},
            "geometry": {
                "coordinates": [
                    [
                        [-0.32388413292315477, 53.73732589790447],
                        [-0.2844094169901439, 53.73884202781184],
                        [-0.24185874916557282, 53.72549820752624],
                        [-0.23878279727406948, 53.77430385636828],
                        [-0.31055500806266423, 53.81821073959722],
                        [-0.3884791226331288, 53.82426325446718],
                        [-0.4499981604528216, 53.79429475800947],
                        [-0.431029790458922, 53.71154332085726],
                        [-0.32388413292315477, 53.73732589790447],
                    ]
                ],
                "type": "Polygon",
            },
        }
    ],
}

_cases = {
    "vulnerability_and_exposure_OSM_only": {
        "dir": "vulnerability_and_exposure_OSM_only",
        "data_catalogue": DATADIR / "hydromt_fiat_catalog_global.yml",
        "configuration": {
            "setup_global_settings": {"crs": "epsg:4326"},
            "setup_output": {
                "output_dir": "output",
                "output_csv_name": "output.csv",
                "output_vector_name": "spatial.gpkg",
            },
            "setup_vulnerability": {
                "vulnerability_fn": "jrc_vulnerability_curves",
                "continent": "Europe",
                "vulnerability_identifiers_and_linking_fn": "jrc_vulnerability_curves_linking",
                "unit": "meters",
            },
            "setup_exposure_buildings": {
                "asset_locations": "OSM",
                "occupancy_type": "OSM",
                "max_potential_damage": "jrc_damage_values",
                "ground_floor_height": 0,
                "damage_types": ["structure", "content"],
                "unit": "meters",
                "country": "United Kingdom",
            },
        },
        "region": _region,
    }
}


@pytest.mark.parametrize("case", list(_cases.keys()))
def test_vulnerability_and_exposure_global_default(case):
    # Read model in examples folder.
    root = EXAMPLEDIR.joinpath(_cases[case]["dir"])
    if root.exists():
        shutil.rmtree(root)

    logger = setuplog("hydromt_fiat", log_level=10)
    data_catalog_yml = str(_cases[case]["data_catalogue"])
    fm = FiatModel(root=root, mode="w", data_libs=[data_catalog_yml], logger=logger)

    region = gpd.GeoDataFrame.from_features(_cases[case]["region"], crs=4326)
    fm.build(region={"geom": region}, opt=_cases[case]["configuration"])
    fm.write()

    # Check if the exposure data exists
    assert root.joinpath("exposure", "buildings.gpkg").exists()
    assert root.joinpath("exposure", "exposure.csv").exists()
    assert root.joinpath("geoms", "region.geojson").exists()

    # Check if the vulnerability data exists
    assert root.joinpath("vulnerability", "vulnerability_curves.csv").exists()

    # Check if the hazard folder exists
    assert root.joinpath("hazard").exists()

    # Check if the output data folder exists
    assert root.joinpath("output").exists()
